@@ -61,8 +61,7 @@ def sub_at_start(apache_conf, root_path, api_target):
 def sub_at_end(apache_conf, root_path, api_target):
     return re.sub(r'</VirtualHost>', f'    ProxyPass {root_path} {api_target}\n    ProxyPassReverse {root_path} {api_target}\n</VirtualHost>', apache_conf)
 
-replace_conf = r"""# The ServerName directive sets the request scheme, hostname and port that
-        #""".strip()
+replace_conf = """# The ServerName directive sets the request scheme, hostname and port that\n\t# the server uses to identify itself.""".strip()
 
 def make_apache_content(apache_conf, root_path, api_target):
 
@@ -83,6 +82,9 @@ def make_apache_content(apache_conf, root_path, api_target):
 # python -m src.bota.apache_utils
 if __name__ == "__main__":
     apache_conf = read_conf().strip()
-    print("before",apache_conf)
-    apache_conf = apache_conf.replace(replace_conf, "")
-    print("after",apache_conf)
\ No newline at end of file
+    print(replace_conf in apache_conf)
+    import json 
+    print(json.dumps(apache_conf))
+    # print("before",apache_conf)
+    
+    # print("after",apache_conf.replace(replace_conf, ""))
\ No newline at end of file
